@@ -1,8 +1,9 @@
 setClass("rose",
-         representation(rho="matrix",
+         slots = c(rho="matrix",
                         cyclVar="numeric",
-                        circle="numeric"),
-         validity=val.rose)
+                        circle="numeric"))
+
+setValidity("rose", val.rose)
 
 setMethod("plot", signature(x = "rose",y = "missing"), plot.rose)
 
